Verfolgen Sie, wie oft Personen, Unternehmen oder Orte im Laufe der Zeit zusammen auftreten
Verfolgen Sie, wie oft Personen, Unternehmen oder Orte im Laufe der Zeit zusammen auftreten. Sehen Sie, ob die Berichterstattung positiv, negativ oder neutral ist, und filtern Sie nach Quelle
Eingabeparameter
| Parameter | Beschreibung | Typ | Standard | Erforderlich |
|---|---|---|---|---|
| entity.id | Mehrere Entitäts-IDs, durch Kommas getrennt. | string | Ja | |
| published_at.start | Startdatum für den Zeitraum. | string | Ja | |
| published_at.end | Enddatum für Zeitbereich. | string | Ja | |
| sort.by | Sortieren nach Sentiment-Score. | string | Ja | |
| sort.order | Absteigende Reihenfolge. | string | Ja | |
| is_duplicate | Duplikate ausschließen. | integer | 0 | Ja |
| api_key | Ihr API Schlüssel | string | Ja | |
| per_page | Maximale Anzahl von abzurufenden Artikeln | integer | 50 | Nein |
Workflow-Beispiele
Sehen Sie, welche Personen, Organisationen und Orte gemeinsam in Artikeln vorkommen:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268,1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY"
Verfolgen Sie Erwähnungen einer Person, Organisation oder eines Ortes im Laufe der Zeit:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268&published_at.start=2022-01-01&published_at.end=2023-12-31&per_page=100&sort.by=published_at&sort.order=asc&api_key=YOUR_API_KEY"
Sehen Sie, welche Personen, Organisationen und Orte zusammen erwähnt werden:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268&organization.name=Tesla&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=published_at&api_key=YOUR_API_KEY"
Sehen Sie, wie sich eine Person, Organisation oder ein Ort darauf auswirkt, ob die Marktabdeckung positiv, negativ oder neutral ist:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268,1282301&category.id=medtop:04000000&sentiment.overall.score.min=0.7&published_at.start=2023-01-01&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY"
Verwandte Beispiele
- Finden Sie, mit welchen Organisationen eine Person erwähnt wird
- Markenreputationsanalyse
- Verfolgen Sie Ihre Konkurrenten
- Filtern Sie Artikel, die Personen erwähnen
- Sortieren nach Engagement-Score
Rezept für cURL
curl --location --globoff --request POST 'https://api.apitube.io/v1/news/everything?entity.id=1278268%2C1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&is_duplicate=0&api_key=YOUR_API_KEY&per_page=50' \
--header 'Content-Type: application/json'
Rezept für Python
import requests
url = "https://api.apitube.io/v1/news/everything"
querystring = {
"entity.id": "1278268,1282301",
"published_at.start": "2023-01-01",
"published_at.end": "2023-12-31",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"is_duplicate": 0,
"api_key": "YOUR_API_KEY",
"per_page": 50
}
response = requests.request("GET", url, params=querystring)
print(response.text)
Rezept für Javascript
import axios from "axios"
const options = {
method: 'GET',
url: 'https://api.apitube.io/v1/news/everything',
params: {
"entity.id": "1278268,1282301",
"published_at.start": "2023-01-01",
"published_at.end": "2023-12-31",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"is_duplicate": 0,
"api_key": "YOUR_API_KEY",
"per_page": 50
}};
axios.request(options).then(function (response) {
console.log(response.data);
}).catch(function (error) {
console.error(error);
});
Rezept für PHP
require 'vendor/autoload.php';
use GuzzleHttp\Client;
$client = new Client();
$response = $client->request('GET', 'https://api.apitube.io/v1/news/everything', [
'query' => [
'entity.id' => '1278268,1282301',
'published_at.start' => '2023-01-01',
'published_at.end' => '2023-12-31',
'sort.by' => 'sentiment.overall.score',
'sort.order' => 'desc',
'is_duplicate' => 0,
'api_key' => 'YOUR_API_KEY',
'per_page' => 50,
],
]);
echo $response->getBody();
Rezept für Java
OkHttpClient client = new OkHttpClient().newBuilder().build();
MediaType mediaType = MediaType.parse("application/json");
RequestBody body = RequestBody.create(mediaType, "");
Request request = new Request.Builder()
.url("https://api.apitube.io/v1/news/everything?entity.id=1278268%2C1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&is_duplicate=0&api_key=YOUR_API_KEY&per_page=50")
.method("POST", body)
.addHeader("Content-Type", "application/json")
.build();
Response response = client.newCall(request).execute();